@@ -3,8 +3,8 @@ from .settings import django_ghost_settings
 
 
 class GhostMember(models.Model):
-    user = models.ForeignKey(
-        django_ghost_settings.get_member_model_string(), on_delete=models.CASCADE
+    sync = models.ForeignKey(
+        django_ghost_settings.get_sync_model_string(), on_delete=models.CASCADE
     )
     email = models.EmailField()
     id = models.CharField(max_length=255, primary_key=True)
